@@ -40,7 +40,7 @@ constOptC <- function(mu, Sinv = NULL, placAdj = FALSE, direction){
               mult*diag(k-1))
   A <- t(tA)
   bvec <- c(1,rep(0,k-1))
-  contr <- solve.QP(D, d, A, bvec, meq=1)$solution
+  contr <- quadprog::solve.QP(D, d, A, bvec, meq=1)$solution
   contr[abs(contr) < 1e-10] <- 0
   if(!placAdj)
     contr <- c(-sum(contr), contr)
@@ -62,7 +62,7 @@ modContr <- function(means, W = NULL, Sinv = NULL, placAdj = FALSE,
     })
   }
   if(all(!ind))
-    stop("All models correspond to a constant shapes, no optimal contrasts calculated.")
+    stop("All models correspond to a constant shape, no optimal contrasts calculated.")
   if(any(!ind)){
     nam <- colnames(means)[!ind]
     namsC <- paste(nam, collapse = ", ")
@@ -112,8 +112,11 @@ optContr <-  function(models, doses, w, S, placAdj = FALSE,
                     nrow=nrow(mu), ncol=ncol(mu))
   }
   type <- match.arg(type)
-  if(type == "constrained")
-    require(quadprog, quietly = TRUE)
+  if(type == "constrained"){
+    avail <- requireNamespace("quadprog", quietly = TRUE)
+    if(!avail)
+      stop("Need suggested package quadprog to calculate constrained contrasts")
+  }
   if(any(doses == 0) & placAdj)
     stop("If placAdj == TRUE there should be no placebo group in \"doses\"")
   ## check for n and vCov arguments 
@@ -206,3 +209,24 @@ plot.optContr <- function (x, superpose = TRUE, xlab = "Dose",
   print(ltplot)
 }
 
+plotContr <- function(optContrObj, xlab = "Dose", ylab = "Contrast coefficients"){
+  if(!inherits(optContrObj, "optContr"))
+    stop("\"optContrObj\" needs to be of class Mods")
+
+  parList <- attr(optContrObj$muMat, "parList")
+  mod_nams <- getModNams(parList)
+  cM <- optContrObj$contMat
+  nD <- nrow(cM)
+  nM <- ncol(cM)
+  cMtr <- data.frame(resp = as.vector(cM),
+                     dose = rep(as.numeric(dimnames(cM)[[1]]), nM),
+                     model = factor(rep(mod_nams, each = nD), levels=mod_nams),
+                     levels = dimnames(cM)[[2]])
+  ggplot(cMtr, aes_string("dose", "resp", col="model"))+
+    geom_line(size=1.2)+
+    geom_point()+
+    theme_bw()+
+    geom_point(size=1.8)+
+    xlab(xlab)+ylab(ylab)+
+    theme(legend.position = "top", legend.title = element_blank())
+}
